@@ -7,34 +7,42 @@ import argparse as __argparse
 import configparser as __configparser
 from os.path import exists as __exists
 from os import makedirs as __makedirs
+from random import choice as __choice 
+import string as _string
 
-__version__ = '0.1.3'
+__version__ = '0.2.0'
 __author__ = 'Saptak De'
 
-config = __configparser.ConfigParser()
+__config = __configparser.ConfigParser()
 
 
 def __main():
     parser = __argparse.ArgumentParser()
 
-    parser.add_argument('-k' , '--Key' , help="Get key of a specific char")
+    SYSTEM_ARGS = [
+        {'com' : '-k' , 'val' : '--Key' , 'help' : 'Get key of a specific char'} ,
+        {'com' : '-copy' , 'val' : '--Copy' , 'help' : 'Get a copy of the keys'} ,
+        {'com' : '-change' , 'val' : '--Type' , 'help' : 'Either change the whole key file or change a specific char'},
+        {'com' : '-genkeys' , 'val' : '--Path' , 'help' : 'Create a keys.json file in root directory'} ,
+        {'com' : '-keypath' , 'val' : '--KeyPath' , 'help' : 'Loaction of keys.json' } ,
+        {'com' : '-version' , 'val' : '--ShowOrNot' , 'help' : 'Outputs installed version of strenc'} ,
+        {'com' : '-config' , 'val' : '--ConfigType' , 'help' : 'Setup or update config(Please run this command at the same folder as keys.json)' } ,
+        {'com' : '-genkeystype' , 'val' : '--GenKeyType' , 'help' : 'Key generator options. Wont work if -genkeys not given'}
 
-    parser.add_argument('-copy' , '--Copy' , help="Get a copy of the keys")
+    ]
+    
+    for command in SYSTEM_ARGS:
+        parser.add_argument(command['com'] , command['val'] , help =command['help'])
 
-    parser.add_argument('-change' , '--Type' , help="Either change the whole key file or change a specific char")
-    parser.add_argument('-genkeys' , '--Path' , help="Create a keys.json file in root directory")
-    parser.add_argument('-keypath' , '--KeyPath' , help="Loaction of keys.json")
-    parser.add_argument('-version' , '--ShowOrNot' , help="Outputs installed version of strenc")
-    parser.add_argument('-config' , '--ConfigType' , help="Setup or update config")
     args = parser.parse_args()
 
     if args.KeyPath:
         path_to_keys = args.KeyPath
     elif __exists('key-config.ini'):
-        config.read('key-config.ini')
+        __config.read('key-config.ini')
 
         try:
-            path_to_keys = config.get('KEYPATH' , 'keypath')
+            path_to_keys = __config.get('KEYPATH' , 'keypath')
         except:
             print('No keypath settings in KEYPATH section in key-config.ini. -k , -copy , -change will not work')    
     else:
@@ -49,7 +57,7 @@ def __main():
         print('Cannot find keys.json from given path. -k , -copy , -change will not work.')
 
 
-
+    type_with_genkeys = False
 
 
 
@@ -85,7 +93,7 @@ def __main():
         try:
             print(f'Key for {args.Key} is : {enc_keys[args.Key]}')
         except:
-            print('-k did not work. Either -keypath is wrong or it is absent. Or the alphabet does not exist in the keys.json file')    
+            print('-k did not work. Either -keypath is wrong or it is absent. Or the character does not exist in the keys.json file')    
     if args.Copy:
         if args.Copy == 'true':
             try:
@@ -98,23 +106,40 @@ def __main():
     
     
     if args.Path:
-        try:
-            if not __exists(args.Path):
-                __makedirs(args.Path)
-            new_key_file = open(f'{args.Path}/keys.json' , 'x')    
-                 
-                            
-            ALPHABETS = 'abcdefghijklmnopqrstuvwxyz1234567890`~!@#$%^&*()-_=+[{]}\\|;:\'\",<.>/?'
-            default_keys = {}
-            for letter in ALPHABETS:
-                character_key = str.lower(input(f'Replace {letter} with : '))
+        if args.GenKeyType:
+            type_with_genkeys = True
+            try:
+                
+                if not __exists(args.Path):
+                    __makedirs(args.Path)
+                new_key_file = open(f'{args.Path}/keys.json' , 'x')
+                ALPHABETS = _string.printable
+                default_keys = {}
+                if args.GenKeyType == 'manual':    
+                    for letter in ALPHABETS:
+                        character_key = str.lower(input(f'Replace {repr(letter)} with : '))
 
-                default_keys[letter] = character_key
-            __json.dump(default_keys , new_key_file , indent=4)
+                        default_keys[letter] = character_key
+                elif args.GenKeyType == 'random':
+                    ALPHABETS_LIST = list(ALPHABETS)
 
-            print(f'Created new keys.json file in {args.Path}')
-        except:
-            print('keys.json already exists')
+                    for letter in ALPHABETS:
+                        random_char = __choice(ALPHABETS_LIST)
+
+                        ALPHABETS_LIST.remove(random_char)
+
+                        default_keys[letter] = random_char
+                else:
+                    print('Either enter "manual" or "random" after -genkeystype. This will result in a empty "keys.json" file')        
+                __json.dump(default_keys , new_key_file , indent=4)
+        
+                print(f'Created new keys.json file in {args.Path}')
+                
+
+            except:
+                print('keys.json already exists')
+        else:
+            print('Please add -genkeystype [manual/random] after -genkeys')    
         
     if args.ShowOrNot:
         if args.ShowOrNot == 'show':
@@ -129,19 +154,19 @@ def __main():
             if not __exists('key-config.ini'):
                 
                 config_file = open('key-config.ini' , 'x')
-                config.read('keys-config.ini')
+                __config.read('keys-config.ini')
                 
 
                 sections_to_add = {'KEYPATH':['keypath'] ,  'DEFAULTKEYVALUES' : []}
 
                 for section,section_settings in sections_to_add.items():
-                    config.add_section(section)
+                    __config.add_section(section)
                     for setting in section_settings:
                         preffered_setting = input(f'Set {setting} from section {section} : ')
 
-                        config.set(section , setting , str.lower(preffered_setting))
+                        __config.set(section , setting , str.lower(preffered_setting))
 
-                config.write(config_file)
+                __config.write(config_file)
                 print('New key-config.ini in root directory is made.')
 
             else:
@@ -149,18 +174,19 @@ def __main():
         else:
             try:
                 config_file = open('key-config.ini' , 'r+')
-                config.read('key-config.ini')
+                __config.read('key-config.ini')
                 config_section , config_settings = args.ConfigType.split('/')
 
                 preffered_setting = input(f'Change {config_settings} from {config_section} : ')
 
-                config.set(config_section , config_settings , preffered_setting)
+                __config.set(config_section , config_settings , preffered_setting)
 
-                config.write(config_file)
+                __config.write(config_file)
                 print(f'Settings {config_settings} from {config_section} is updated to {preffered_setting}') 
             except:
                 print('key-config.ini does not exists. run -config setup to generate a new one.Or the specific setting does not exists')    
-
-            
+    
+    if args.GenKeyType and not type_with_genkeys:
+        print('Run -genkeystype alongside -genkeys')        
 
 
